.. _configuration:

######################
Configuration settings
######################

In this section, we present the main configuration classes used by kafkaconnect.
Note that the configuration for the supported connectors is done in the kafka-connect-manager `Helm chart`_.


.. _Helm chart: https://github.com/lsst-sqre/charts/tree/master/charts/kafka-connect-manager


.. automodapi:: kafkaconnect.config

.. automodapi:: kafkaconnect.influxdb_sink.config
